import 'package:auto_size_text/auto_size_text.dart';
import 'package:flutter/material.dart';

class DownloadAppsContainer extends StatefulWidget {
  const DownloadAppsContainer({
    @required this.texts,
    this.backgroundImage,
    this.backgroundColor,
    @required this.titleColor,
    @required this.subtitleColor,
    @required this.image1,
    @required this.image2,
    @required this.androidUrl,
    @required this.iosUrl,
  });

  final List<String> texts;
  final String backgroundImage;
  final Color backgroundColor;
  final Color titleColor;
  final Color subtitleColor;
  final String image1;
  final String image2;
  final String androidUrl;
  final String iosUrl;

  @override
  _DownloadAppsContainerState createState() => _DownloadAppsContainerState();
}

class _DownloadAppsContainerState extends State<DownloadAppsContainer> {
  double currentPage = 0;
  final PageController pageController = PageController(initialPage: 0);

  @override
  Widget build(BuildContext context) {
    bool isPortrait =
        MediaQuery.of(context).size.width > MediaQuery.of(context).size.height
            ? false
            : true;

    var widgetsList = <Widget>[
      Spacer(flex: 2),
      Expanded(
        flex: isPortrait ? 6 : 4,
        child: Card(
          elevation: 5,
          child: Container(
            decoration: BoxDecoration(
              image: DecorationImage(
                fit: BoxFit.fitWidth,
                image: AssetImage(
                  widget.image1,
                ),
              ),
            ),
          ),
        ),
      ),
      Spacer(flex: 1),
      Expanded(
        flex: 4,
        child: Column(
          children: <Widget>[
            Spacer(flex: 1),
            Expanded(
              flex: isPortrait ? 4 : 1,
              child: Text(
                widget.texts[2],
                textAlign: TextAlign.left,
                style: TextStyle(
                  color: widget.subtitleColor,
                  fontSize: 22,
                  //fontWeight: FontWeight.bold,
                ),
              ),
            ),
            Spacer(flex: 1),
          ],
        ),
      ),
      Spacer(flex: 2),
    ];

    return Container(
      decoration: BoxDecoration(
        image: widget.backgroundImage != null
            ? DecorationImage(
                fit: BoxFit.fitHeight,
                image: AssetImage(
                  widget.backgroundImage,
                ),
              )
            : null,
        color: widget.backgroundColor,
      ),
      height: isPortrait
          ? (MediaQuery.of(context).size.height * 2)
          : (MediaQuery.of(context).size.height),
      child: FractionallySizedBox(
        widthFactor: isPortrait ? 0.8 : 1,
        child: Column(
          children: <Widget>[
            isPortrait ? Container() : Spacer(flex: 1),
            Expanded(
              flex: 2,
              child: AutoSizeText(
                widget.texts[0],
                textAlign: TextAlign.left,
                style: TextStyle(
                  color: widget.titleColor,
                  fontSize: 40,
                  fontWeight: FontWeight.bold,
                ),
                minFontSize: 30,
                maxLines: 4,
                overflow: TextOverflow.clip,
              ),
            ),
            isPortrait ? Container() : Spacer(flex: 1),
            Expanded(
              flex: 6,
              child: Flex(
                  direction: isPortrait ? Axis.vertical : Axis.horizontal,
                  children: <Widget>[
                    Spacer(flex: 2),
                    Expanded(
                      flex: 4,
                      child: Column(
                        children: <Widget>[
                          Spacer(flex: 1),
                          Expanded(
                            flex: isPortrait ? 4 : 1,
                            child: Text(
                              widget.texts[1],
                              textAlign: TextAlign.left,
                              style: TextStyle(
                                color: widget.subtitleColor,
                                fontSize: 22,
                                //fontWeight: FontWeight.bold,
                              ),
                            ),
                          ),
                          Spacer(flex: 1),
                        ],
                      ),
                    ),
                    Spacer(flex: 1),
                    Expanded(
                      flex: isPortrait ? 6 : 4,
                      child: Card(
                        elevation: 5,
                        child: Container(
                          decoration: BoxDecoration(
                            image: DecorationImage(
                              fit: BoxFit.fitWidth,
                              image: AssetImage(
                                widget.image2,
                              ),
                            ),
                          ),
                        ),
                      ),
                    ),
                    Spacer(flex: 2),
                  ]),
            ),
            isPortrait ? Container() : Spacer(flex: 1),
            Expanded(
              flex: 6,
              child: Flex(
                direction: isPortrait ? Axis.vertical : Axis.horizontal,
                children:
                    isPortrait ? widgetsList.reversed.toList() : widgetsList,
              ),
            ),
            isPortrait ? Container() : Spacer(flex: 1),
            Expanded(
              flex: 6,
              child: Flex(
                direction: isPortrait ? Axis.vertical : Axis.horizontal,
                children: <Widget>[
                  Spacer(flex: 2),
                  Expanded(
                    flex: 4,
                    child: Column(
                      children: <Widget>[
                        isPortrait ? Container() : Spacer(flex: 1),
                        Expanded(
                          flex: isPortrait ? 20 : 1,
                          child: Text(
                            widget.texts[3],
                            textAlign: TextAlign.left,
                            style: TextStyle(
                              color: widget.subtitleColor,
                              fontSize: 22,
                              //fontWeight: FontWeight.bold,
                            ),
                          ),
                        ),
                        Spacer(flex: 1),
                      ],
                    ),
                  ),
                  Spacer(flex: 1),
                  Expanded(
                    flex: isPortrait ? 6 : 4,
                    child: Column(
                      children: <Widget>[
                        Expanded(
                          flex: 8,
                          child: FlatButton(
                            onPressed: () {
                              Scaffold.of(context).showSnackBar(SnackBar(
                                content: Text("Coming soon 👍"),
                                duration: Duration(seconds: 1),
                              ));
                              //launchInBrowser(widget.androidUrl);
                            },
                            child: Container(
                              decoration: BoxDecoration(
                                color: Colors.transparent,
                                image: DecorationImage(
                                  fit: BoxFit.fitHeight,
                                  image: AssetImage(
                                    'assets/images/mobile_stores/google_badge_en.png',
                                  ),
                                ),
                              ),
                            ),
                          ),
                        ),
                        Expanded(
                          flex: 6,
                          child: FlatButton(
                            onPressed: () {
                              Scaffold.of(context).showSnackBar(SnackBar(
                                content: Text("Coming soon 👍"),
                                duration: Duration(seconds: 1),
                              ));
                              //launchInBrowser(widget.iosUrl);
                            },
                            child: Container(
                              decoration: BoxDecoration(
                                color: Colors.transparent,
                                image: DecorationImage(
                                  fit: BoxFit.fitHeight,
                                  image: AssetImage(
                                    'assets/images/mobile_stores/apple_badge_en.png',
                                  ),
                                ),
                              ),
                            ),
                          ),
                        ),
                      ],
                    ),
                  ),
                  Spacer(flex: 2),
                ],
              ),
            ),
            isPortrait ? Container() : Spacer(flex: 1),
          ],
        ),
      ),
    );
  }
}
